@@ -1,25 +1,13 @@
-/*
-* Copyright (C) 2019 ~ 2020 UnionTech Software Technology Co.,Ltd
-*
-* Author:     linxun <linxun@uniontech.com>
-* Maintainer:  linxun <linxun@uniontech.com>
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-* GNU General Public License for more details.
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "logauththread.h"
 #include "structdef.h"
 #include "sharedmemorymanager.h"
 #include "wtmpparse.h"
 #include "dldbushandler.h"
+#include "qtcompat.h"
 
 #include <stub.h>
 
@@ -108,6 +96,20 @@ QString stub_dnfReadLog(const QString &filePath)
     return "2021-05-21T02:08:36Z DEBUG 加载插件：builddep, changelog, \nconfig-manager, copr, debug, debuginfo-install, download, \ngenerate_completion_cache, needs-restarting, playground, repoclosure, repodiff, repograph, repomanage, reposync";
 }
 
+QString stub_dnfReadStream(const QString &filePath)
+{
+    Q_UNUSED(filePath);
+    static int i = 0;
+    QString result;
+    if(i % 2 == 0) {
+        result = "2021-05-21T02:08:36Z DEBUG 加载插件：builddep, changelog, \nconfig-manager, copr, debug, debuginfo-install, download, \ngenerate_completion_cache, needs-restarting, playground, repoclosure, repodiff, repograph, repomanage, reposync";
+    } else {
+        result = "";
+    }
+    ++i;
+    return result;
+}
+
 QString stub_BootReadLog(const QString &filePath)
 {
     Q_UNUSED(filePath);
@@ -131,15 +133,16 @@ qint64 dnfToMSecsSinceEpoch()
     return 1999999999999999999;
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 int dmesgIndexIn(const QString &str, int offset = 0, QRegExp::CaretMode caretMode = QRegExp::CaretAtZero)
 {
+    Q_UNUSED(caretMode);
     Q_UNUSED(str);
     Q_UNUSED(offset);
-    Q_UNUSED(caretMode);
     return 1;
 }
 
-QString &dmesgReplace(const QRegExp &rx, const QString &after)
+QString &dmesgReplace(const REG_EXP &rx, const QString &after)
 {
     Q_UNUSED(rx);
     Q_UNUSED(after);
@@ -156,6 +159,7 @@ QStringList dmesgCapturedTexts()
                          << "test"
                          << "NID=0x8";
 }
+#endif
 
 void handleFile()
 {
@@ -167,16 +171,16 @@ public:
     //添加日志
     static void SetUpTestCase()
     {
-        qDebug() << "SetUpTestCase" << endl;
+        qDebug() << "SetUpTestCase" << ENDL;
     }
     static void TearDownTestCase()
     {
-        qDebug() << "TearDownTestCase" << endl;
+        qDebug() << "TearDownTestCase" << ENDL;
     }
     void SetUp() //TEST跑之前会执行SetUp
     {
-        m_logAuthThread = LogAuthThread::instance();
-        qDebug() << "SetUp" << endl;
+        m_logAuthThread = new LogAuthThread();
+        qDebug() << "SetUp" << ENDL;
     }
     void TearDown() //TEST跑完之后会执行TearDown
     {
@@ -333,12 +337,16 @@ TEST_F(LogAuthThread_UT, UT_HandleKern_001)
     stub.set(wtmp_close, stub_wtmp_close);
     stub.set(ADDR(QProcess, setProcessChannelMode), stub_setProcessChannelMode);
     stub.set(ADDR(QProcess, exitCode), stub_exitCode);
-    stub.set(ADDR(DLDBusHandler, readLog), stub_dnfReadLog);
+    stub.set(ADDR(DLDBusHandler, openLogStream), stub_dnfReadLog);
+    stub.set(ADDR(DLDBusHandler, readLogInStream), stub_dnfReadStream);
     stub.set((QByteArray(QIODevice::*)(qint64))ADDR(QIODevice, readLine), fileReadLine);
     stub.set(ADDR(QDateTime, toMSecsSinceEpoch), dnfToMSecsSinceEpoch);
-    stub.set(ADDR(QRegExp, indexIn), dmesgIndexIn);
-    stub.set((QString & (QString::*)(const QRegExp &, const QString &)) ADDR(QString, replace), dmesgReplace);
-    stub.set((QStringList(QRegExp::*)())ADDR(QRegExp, capturedTexts), dmesgCapturedTexts);
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    stub.set(ADDR(REG_EXP, indexIn), dmesgIndexIn);
+    stub.set((QStringList(REG_EXP::*)())ADDR(REG_EXP, capturedTexts), dmesgCapturedTexts);
+    stub.set((QString & (QString::*)(const REG_EXP &, const QString &)) ADDR(QString, replace), dmesgReplace);
+#endif
     m_logAuthThread->m_FilePath = QStringList() << "/test" << "/xorg.old";
     m_logAuthThread->m_canRun=true;
     m_logAuthThread->handleKern();
@@ -368,9 +376,12 @@ TEST_F(LogAuthThread_UT, UT_HandleDmesg_001)
     stub.set(ADDR(DLDBusHandler, readLog), stub_KernReadLog);
     stub.set((QByteArray(QIODevice::*)(qint64))ADDR(QIODevice, readLine), fileReadLine);
     stub.set(ADDR(QDateTime, toMSecsSinceEpoch), dnfToMSecsSinceEpoch);
-    stub.set(ADDR(QRegExp, indexIn), dmesgIndexIn);
-    stub.set((QString & (QString::*)(const QRegExp &, const QString &)) ADDR(QString, replace), dmesgReplace);
-    stub.set((QStringList(QRegExp::*)())ADDR(QRegExp, capturedTexts), dmesgCapturedTexts);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    stub.set(ADDR(REG_EXP, indexIn), dmesgIndexIn);
+    stub.set((QString & (QString::*)(const REG_EXP &, const QString &)) ADDR(QString, replace), dmesgReplace);
+    stub.set((QStringList(REG_EXP::*)())ADDR(REG_EXP, capturedTexts), dmesgCapturedTexts);
+#endif
+
     m_logAuthThread->m_FilePath = QStringList() << "/test"<< "/xorg.old";
     m_logAuthThread->m_canRun=true;
     m_logAuthThread->handleDmesg();
@@ -398,9 +409,11 @@ TEST_F(LogAuthThread_UT, handleBoot_UT_001)
     stub.set(ADDR(DLDBusHandler, readLog), stub_BootReadLog);
     stub.set((QByteArray(QIODevice::*)(qint64))ADDR(QIODevice, readLine), fileReadLine);
     stub.set(ADDR(QDateTime, toMSecsSinceEpoch), dnfToMSecsSinceEpoch);
-    stub.set(ADDR(QRegExp, indexIn), dmesgIndexIn);
-    stub.set((QString & (QString::*)(const QRegExp &, const QString &)) ADDR(QString, replace), dmesgReplace);
-    stub.set((QStringList(QRegExp::*)())ADDR(QRegExp, capturedTexts), dmesgCapturedTexts);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    stub.set(ADDR(REG_EXP, indexIn), dmesgIndexIn);
+    stub.set((QString & (QString::*)(const REG_EXP &, const QString &)) ADDR(QString, replace), dmesgReplace);
+    stub.set((QStringList(REG_EXP::*)())ADDR(REG_EXP, capturedTexts), dmesgCapturedTexts);
+#endif
     m_logAuthThread->m_FilePath = QStringList() << "/test"<< "/xorg.old";
     m_logAuthThread->m_canRun=true;
     m_logAuthThread->handleBoot();
@@ -428,9 +441,11 @@ TEST_F(LogAuthThread_UT, handleKwin_UT_001)
     stub.set(ADDR(DLDBusHandler, readLog), stub_BootReadLog);
     stub.set((QByteArray(QIODevice::*)(qint64))ADDR(QIODevice, readLine), fileReadLine);
     stub.set(ADDR(QDateTime, toMSecsSinceEpoch), dnfToMSecsSinceEpoch);
-    stub.set(ADDR(QRegExp, indexIn), dmesgIndexIn);
-    stub.set((QString & (QString::*)(const QRegExp &, const QString &)) ADDR(QString, replace), dmesgReplace);
-    stub.set((QStringList(QRegExp::*)())ADDR(QRegExp, capturedTexts), dmesgCapturedTexts);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    stub.set(ADDR(REG_EXP, indexIn), dmesgIndexIn);
+    stub.set((QString & (QString::*)(const REG_EXP &, const QString &)) ADDR(QString, replace), dmesgReplace);
+    stub.set((QStringList(REG_EXP::*)())ADDR(REG_EXP, capturedTexts), dmesgCapturedTexts);
+#endif
     m_logAuthThread->m_FilePath = QStringList() << "/test"<< "/xorg.old";
     m_logAuthThread->m_canRun=true;
     m_logAuthThread->handleKwin();
@@ -458,9 +473,11 @@ TEST_F(LogAuthThread_UT, handleDpkg_UT_001)
     stub.set(ADDR(DLDBusHandler, readLog), stub_BootReadLog);
     stub.set((QByteArray(QIODevice::*)(qint64))ADDR(QIODevice, readLine), fileReadLine);
     stub.set(ADDR(QDateTime, toMSecsSinceEpoch), dnfToMSecsSinceEpoch);
-    stub.set(ADDR(QRegExp, indexIn), dmesgIndexIn);
-    stub.set((QString & (QString::*)(const QRegExp &, const QString &)) ADDR(QString, replace), dmesgReplace);
-    stub.set((QStringList(QRegExp::*)())ADDR(QRegExp, capturedTexts), dmesgCapturedTexts);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    stub.set(ADDR(REG_EXP, indexIn), dmesgIndexIn);
+    stub.set((QString & (QString::*)(const REG_EXP &, const QString &)) ADDR(QString, replace), dmesgReplace);
+    stub.set((QStringList(REG_EXP::*)())ADDR(REG_EXP, capturedTexts), dmesgCapturedTexts);
+#endif
     m_logAuthThread->m_FilePath = QStringList() << "/test"<< "/xorg.old";
     m_logAuthThread->m_canRun=true;
     m_logAuthThread->handleDkpg();
@@ -488,9 +505,11 @@ TEST_F(LogAuthThread_UT, handleNormal_UT_001)
     stub.set(ADDR(DLDBusHandler, readLog), stub_BootReadLog);
     stub.set((QByteArray(QIODevice::*)(qint64))ADDR(QIODevice, readLine), fileReadLine);
     stub.set(ADDR(QDateTime, toMSecsSinceEpoch), dnfToMSecsSinceEpoch);
-    stub.set(ADDR(QRegExp, indexIn), dmesgIndexIn);
-    stub.set((QString & (QString::*)(const QRegExp &, const QString &)) ADDR(QString, replace), dmesgReplace);
-    stub.set((QStringList(QRegExp::*)())ADDR(QRegExp, capturedTexts), dmesgCapturedTexts);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    stub.set(ADDR(REG_EXP, indexIn), dmesgIndexIn);
+    stub.set((QString & (QString::*)(const REG_EXP &, const QString &)) ADDR(QString, replace), dmesgReplace);
+    stub.set((QStringList(REG_EXP::*)())ADDR(REG_EXP, capturedTexts), dmesgCapturedTexts);
+#endif
     m_logAuthThread->m_FilePath = QStringList() << "/test"<< "/xorg.old";
     m_logAuthThread->m_canRun=true;
     m_logAuthThread->handleNormal();
