@@ -1,19 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 UnionTech Software Technology Co.,Ltd
-*
-* Author:     zyc <zyc@uniontech.com>
-* Maintainer:  zyc <zyc@uniontech.com>
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-* GNU General Public License for more details.
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef STUBALLTHREAD_H
 #define STUBALLTHREAD_H
 #include "structdef.h"
@@ -34,6 +22,7 @@ void LogFileParser_parseByKern(KERN_FILTERS &iKernFilter);
 void LogFileParser_parseByApp(APP_FILTERS &iAPPFilter);
 void LogFileParser_parseByNormal(QList<LOG_MSG_NORMAL> &nList, NORMAL_FILTERS &iNormalFiler); // add by Airy
 void LogFileParser_parseByKwin(KWIN_FILTERS iKwinfilter);
+void LogFileParser_parseByOOC(QString & path);
 void Doc_Document_save(const QString &path);
 void QRunnable_run();
 #endif // STUBALLTHREAD_H
