@@ -90,7 +90,7 @@
     </message>
     <message>
         <source>Info</source>
-        <translation>Të dhëna</translation>
+        <translation>Hollësi</translation>
     </message>
     <message>
         <source>Debug</source>
@@ -122,19 +122,19 @@
     </message>
     <message>
         <source>Discretionary Access Control</source>
-        <translation type="unfinished"/>
+        <translation>Kontrolli Diskretional</translation>
     </message>
     <message>
         <source>Mandatory access control</source>
-        <translation type="unfinished"/>
+        <translation>Kontrolli Obligatorike</translation>
     </message>
     <message>
         <source>Remote</source>
-        <translation type="unfinished"/>
+        <translation>Remote</translation>
     </message>
     <message>
         <source>Document audit</source>
-        <translation type="unfinished"/>
+        <translation>Audita Dokumente</translation>
     </message>
     <message>
         <source>Other</source>
@@ -149,7 +149,7 @@
     </message>
     <message>
         <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
-        <translation>TEKS (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
+        <translation>TEKST (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
     </message>
 </context>
 <context>
@@ -256,7 +256,7 @@
     </message>
     <message>
         <source>Info</source>
-        <translation>Info</translation>
+        <translation>Hollësi</translation>
     </message>
     <message>
         <source>Error</source>
@@ -332,7 +332,7 @@
     </message>
     <message>
         <source>Info</source>
-        <translation>Info</translation>
+        <translation>Hollësi</translation>
     </message>
     <message>
         <source>User</source>
@@ -380,7 +380,7 @@
     </message>
     <message>
         <source>Null</source>
-        <translation type="unfinished"/>
+        <translation>Nëjë</translation>
     </message>
     <message>
         <source>User:</source>
@@ -400,15 +400,15 @@
     </message>
     <message>
         <source>SIG</source>
-        <translation type="unfinished"/>
+        <translation>SIG</translation>
     </message>
     <message>
         <source>EXE</source>
-        <translation type="unfinished"/>
+        <translation>EXE</translation>
     </message>
     <message>
         <source>Core File</source>
-        <translation type="unfinished"/>
+        <translation>Fajll Core</translation>
     </message>
     <message>
         <source>User Name </source>
@@ -416,7 +416,7 @@
     </message>
     <message>
         <source>Offset</source>
-        <translation type="unfinished"/>
+        <translation>Offset</translation>
     </message>
 </context>
 <context>
@@ -450,7 +450,7 @@
     </message>
     <message>
         <source>Xorg Log</source>
-        <translation>Regjistër Xorg</translation>
+        <translation>Regjistër Xorg-u</translation>
     </message>
     <message>
         <source>Application Log</source>
@@ -485,7 +485,7 @@
     <name>Waring</name>
     <message>
         <source>Unable to obtain crash information, please install systemd-coredump.</source>
-        <translation>S’u arrit të merrej informacion vithisjeje, ju lutemi, instaloni systemd-coredump.</translation>
+        <translation>S’u arrit të merreshin hollësi vithisjeje, ju lutemi, instaloni systemd-coredump.</translation>
     </message>
 </context>
 <context>
@@ -500,6 +500,10 @@
         <translation>Shkallë sigurie për sistemin e tanishëm: e lartë
  auditim: vetëm përgjegjësit mund të shohin regjistër auditimesh</translation>
     </message>
+    <message>
+        <source>Audit log is not exist.</source>
+        <translation>Regjistro Audita nuk ekziston.</translation>
+    </message>
 </context>
 <context>
     <name>main</name>
@@ -525,7 +529,7 @@
     </message>
     <message>
         <source>SELF APPNAME</source>
-        <translation type="unfinished"/>
+        <translation>SELF APPNEM</translation>
     </message>
     <message>
         <source>Export logs within a specified time period</source>
@@ -569,7 +573,7 @@
     </message>
     <message>
         <source>Report coredump informations.</source>
-        <translation type="unfinished"/>
+        <translation>Raporto informacione për coredump.</translation>
     </message>
     <message>
         <source>Export logs based on app submodel</source>
@@ -588,15 +592,15 @@
     </message>
     <message>
         <source>10 sec</source>
-        <translation>10 sek.</translation>
+        <translation>10s</translation>
     </message>
     <message>
         <source>1 min</source>
-        <translation>1 min.</translation>
+        <translation>1m</translation>
     </message>
     <message>
         <source>5 min</source>
-        <translation>5 min</translation>
+        <translation>5m</translation>
     </message>
     <message>
         <source>No refresh</source>
